All Classes and Interfaces
Classes
Class
Description
Class defining an adduct object in a MolecularFormula.
A AminoAcid is Monomer which stores additional amino acid specific
informations, like the N-terminus atom.
Represents the idea of an chemical atom.
This class should not be used directly.
Base class for all chemical objects that maintain a list of Atoms and
ElectronContainers.
A set of AtomContainers.
The base class for atom types.
A BioPolymer is a subclass of a Polymer which is supposed to store
additional informations about the Polymer which are connected to BioPolymers.
Implements the concept of a covalent bond between two or more atoms.
A Object containing a number of ChemSequences.
An object containing multiple MoleculeSet and
the other lower level concepts like rings, sequences,
fragments, etc.
The base class for all chemical objects in this cdk.
Event fired by cdk classes to their registered listeners
in case something changes within them.
A sequence of ChemModels, which can, for example, be used to
store the course of a reaction.
A memory-efficient data structure to store conformers for a single molecule.
Class representing a molecular crystal.
A factory class to provide implementation independent
ICDKObjects.Base class for entities containing electrons, like bonds, orbitals, lone-pairs.
Implements the idea of an element in the periodic table.
Class to represent an IPseudoAtom which embeds an IAtomContainer.
Used to store and retrieve data of a particular isotope.
A LonePair is an orbital primarily located with one Atom, containing
two electrons.
A Mapping is an relation between two ChemObjects in a non-chemical
entity.
Class defining a molecular formula object.
Class defining an set object of MolecularFormulas.
A Monomer is an AtomContainer which stores additional monomer specific
informations for a group of Atoms.
Represents the idea of an atom as used in PDB files.
Represents the idea of an monomer as used in PDB files.
An entry in the PDB database.
Holder for secundary protein structure elements.
Subclass of Molecule to store Polymer specific attributes that a Polymer has.
Represents the idea of a non-chemical atom-like entity, like Me,
R, X, Phe, His, etc.
Represents the idea of a chemical reaction.
Classes that extends the definition of reaction to a scheme.
A set of reactions, for example those taking part in a reaction.
Class representing a ring structure in a molecule.
Maintains a set of Ring objects.
A Single Electron is an orbital which is occupied by only one electron.
A Strand is an AtomContainer which stores additional strand specific
informations for a group of Atoms.
An implementation of the
ISubstance interface.This class contains methods for generating simple organic molecules and is
copy of
MoleculeFactory for use in tests.