Package org.openscience.cdk
Class BioPolymer
java.lang.Object
org.openscience.cdk.ChemObject
org.openscience.cdk.AtomContainer
org.openscience.cdk.Polymer
org.openscience.cdk.BioPolymer
- All Implemented Interfaces:
Serializable,Cloneable,IAtomContainer,IBioPolymer,ICDKObject,IChemObject,IChemObjectListener,IPolymer
- Direct Known Subclasses:
PDBPolymer
A BioPolymer is a subclass of a Polymer which is supposed to store
additional informations about the Polymer which are connected to BioPolymers.
- Author:
- Edgar Luttmann <[email protected]>, Martin Eklund
- See Also:
- Keywords:
- polymer, biopolymer
- Created on:
- 2001-08-06
-
Field Summary
Fields inherited from interface org.openscience.cdk.interfaces.IChemObject
ALIPHATIC, AROMATIC, CONJUGATED, HYDROGEN_BOND_ACCEPTOR, HYDROGEN_BOND_DONOR, IN_RING, MAPPED, MARKUSH, NOT_IN_RING, PLACED, REACTIVE_CENTER, SINGLE_OR_DOUBLE, TYPEABLE, VISITED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidAdds the atom to a specified Strand and a specified Monomer.voidAdds the atom oAtom to a specified Strand, whereas the Monomer is unspecified.clone()Clones thisIChemObject.getMonomer(String monName, String strandName) Retrieves a Monomer object by specifying its name.intReturns the number of monomers present in BioPolymer.Returns a collection of the names of allMonomers in this BioPolymer.Retrieves a Monomer object by specifying its name.intReturns the number of strands present in the BioPolymer.Returns a collection of the names of allStrands in this BioPolymer.voidremoveStrand(String name) Removes a particular strand, specified by its name.toString()Methods inherited from class org.openscience.cdk.Polymer
addAtom, getMonomer, removeMonomerMethods inherited from class org.openscience.cdk.AtomContainer
add, addAtom, addBond, addBond, addBond, addElectronContainer, addLonePair, addLonePair, addSingleElectron, addSingleElectron, addStereoElement, atoms, bonds, contains, contains, contains, contains, contains, electronContainers, getAtom, getAtomCount, getAtomNumber, getBond, getBond, getBondCount, getBondNumber, getBondNumber, getBondOrderSum, getConnectedAtomsCount, getConnectedAtomsList, getConnectedBondsCount, getConnectedBondsCount, getConnectedBondsList, getConnectedElectronContainersList, getConnectedLonePairsCount, getConnectedLonePairsList, getConnectedSingleElectronsCount, getConnectedSingleElectronsList, getElectronContainer, getElectronContainerCount, getFirstAtom, getLastAtom, getLonePair, getLonePairCount, getLonePairNumber, getMaximumBondOrder, getMinimumBondOrder, getSingleElectron, getSingleElectronCount, getSingleElectronNumber, getTitle, indexOf, indexOf, indexOf, indexOf, isEmpty, lonePairs, newAtom, newAtom, newBond, remove, removeAllBonds, removeAllElectronContainers, removeAllElements, removeAtom, removeAtom, removeAtomAndConnectedElectronContainers, removeAtomOnly, removeAtomOnly, removeBond, removeBond, removeBond, removeElectronContainer, removeElectronContainer, removeLonePair, removeLonePair, removeSingleElectron, removeSingleElectron, setAtom, setAtoms, setBonds, setStereoElements, setTitle, shallowCopy, singleElectrons, stateChanged, stereoElementsMethods inherited from class org.openscience.cdk.ChemObject
addListener, addProperties, clear, compare, flags, getBuilder, getFlag, getFlags, getFlagValue, getID, getListenerCount, getNotification, getProperties, getProperty, getProperty, is, notifyChanged, notifyChanged, removeListener, removeProperty, set, setFlag, setFlags, setID, setNotification, setProperties, setPropertyMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.openscience.cdk.interfaces.IAtomContainer
add, addBond, addBond, addBond, addBond, addElectronContainer, addLonePair, addLonePair, addSingleElectron, addSingleElectron, addStereoElement, atoms, bonds, contains, contains, contains, contains, contains, electronContainers, getAtom, getAtomCount, getAtomNumber, getBond, getBond, getBondCount, getBondNumber, getBondNumber, getBondOrderSum, getConnectedAtomsCount, getConnectedAtomsList, getConnectedBondsCount, getConnectedBondsCount, getConnectedBondsList, getConnectedElectronContainersList, getConnectedLonePairsCount, getConnectedLonePairsList, getConnectedSingleElectronsCount, getConnectedSingleElectronsList, getElectronContainer, getElectronContainerCount, getFirstAtom, getLastAtom, getLonePair, getLonePairCount, getLonePairNumber, getMaximumBondOrder, getMinimumBondOrder, getSingleElectron, getSingleElectronCount, getSingleElectronNumber, getTitle, indexOf, indexOf, indexOf, indexOf, isEmpty, lonePairs, newAtom, newAtom, newAtom, newAtom, newBond, newBond, remove, removeAllBonds, removeAllElectronContainers, removeAllElements, removeAtom, removeAtom, removeAtomAndConnectedElectronContainers, removeAtomOnly, removeAtomOnly, removeBond, removeBond, removeBond, removeElectronContainer, removeElectronContainer, removeLonePair, removeLonePair, removeSingleElectron, removeSingleElectron, setAtom, setAtoms, setBonds, setStereoElements, setTitle, singleElectrons, stereoElementsMethods inherited from interface org.openscience.cdk.interfaces.IBioPolymer
addAtomMethods inherited from interface org.openscience.cdk.interfaces.ICDKObject
getBuilderMethods inherited from interface org.openscience.cdk.interfaces.IChemObject
addListener, addProperties, clear, flags, getFlag, getFlags, getFlagValue, getID, getListenerCount, getNotification, getProperties, getProperty, getProperty, is, notifyChanged, notifyChanged, removeListener, removeProperty, set, setFlag, setFlags, setID, setNotification, setProperties, setPropertyMethods inherited from interface org.openscience.cdk.interfaces.IChemObjectListener
stateChangedMethods inherited from interface org.openscience.cdk.interfaces.IPolymer
addAtom, getMonomer, removeMonomer
-
Constructor Details
-
BioPolymer
public BioPolymer()Constructs a new Polymer to store the Strands.
-
-
Method Details
-
addAtom
Adds the atom oAtom to a specified Strand, whereas the Monomer is unspecified. Hence the atom will be added to a Monomer of type UNKNOWN in the specified Strand.- Specified by:
addAtomin interfaceIBioPolymer- Parameters:
oAtom- The atom to addoStrand- The strand the atom belongs to
-
addAtom
Adds the atom to a specified Strand and a specified Monomer.- Specified by:
addAtomin interfaceIBioPolymer- Parameters:
oAtom-oMonomer-oStrand-
-
getMonomerCount
public int getMonomerCount()Returns the number of monomers present in BioPolymer.- Specified by:
getMonomerCountin interfaceIBioPolymer- Specified by:
getMonomerCountin interfaceIPolymer- Overrides:
getMonomerCountin classPolymer- Returns:
- number of monomers
-
getMonomer
Retrieves a Monomer object by specifying its name. [You have to specify the strand to enable monomers with the same name in different strands. There is at least one such case: every strand contains a monomer called "".]- Specified by:
getMonomerin interfaceIBioPolymer- Parameters:
monName- The name of the monomer to look for- Returns:
- The Monomer object which was asked for
-
getMonomerNames
Returns a collection of the names of allMonomers in this BioPolymer.- Specified by:
getMonomerNamesin interfaceIBioPolymer- Specified by:
getMonomerNamesin interfaceIPolymer- Overrides:
getMonomerNamesin classPolymer- Returns:
- a
Collectionof all the monomer names.
-
getStrandCount
public int getStrandCount()Returns the number of strands present in the BioPolymer.- Specified by:
getStrandCountin interfaceIBioPolymer- Returns:
- number of strands
-
getStrand
Retrieves a Monomer object by specifying its name.- Specified by:
getStrandin interfaceIBioPolymer- Parameters:
cName- The name of the monomer to look for- Returns:
- The Monomer object which was asked for
-
getStrandNames
Returns a collection of the names of allStrands in this BioPolymer.- Specified by:
getStrandNamesin interfaceIBioPolymer- Returns:
- a
Collectionof all the strand names.
-
removeStrand
Removes a particular strand, specified by its name.- Specified by:
removeStrandin interfaceIBioPolymer- Parameters:
name- name of the strand to remove
-
getStrands
- Specified by:
getStrandsin interfaceIBioPolymer- Returns:
- hashtable containing the monomers in the strand.
-
toString
Description copied from class:AtomContainer- Specified by:
toStringin interfaceIChemObject- Overrides:
toStringin classPolymer
-
clone
Description copied from class:AtomContainerClones thisIChemObject. It clones the identifier, flags, properties and pointer vectors. The ChemObjectListeners are not cloned, and neither is the content of the pointer vectors.- Specified by:
clonein interfaceIAtomContainer- Specified by:
clonein interfaceIBioPolymer- Specified by:
clonein interfaceIChemObject- Specified by:
clonein interfaceIPolymer- Overrides:
clonein classPolymer- Returns:
- The cloned object
- Throws:
CloneNotSupportedException
-