Class Mapping

All Implemented Interfaces:
Serializable, Cloneable, ICDKObject, IChemObject, IMapping

public class Mapping extends ChemObject implements Serializable, Cloneable, IMapping
A Mapping is an relation between two ChemObjects in a non-chemical entity. It is not a Bond, nor a Association, merely a relation. An example of such a mapping, is the mapping between corresponding atoms in a Reaction.
Author:
Egon Willighagen
See Also:
Keywords:
reaction, atom mapping
Created on:
2003-08-16
  • Constructor Details

    • Mapping

      public Mapping(IChemObject objectOne, IChemObject objectTwo)
      Constructs an unconnected lone pair.
      Parameters:
      objectOne - The first IChemObject of the mapping
      objectTwo - The second IChemObject of the mapping
  • Method Details