Class ReactionSet

java.lang.Object
org.openscience.cdk.ChemObject
org.openscience.cdk.ReactionSet
All Implemented Interfaces:
Serializable, Cloneable, ICDKObject, IChemObject, IChemObjectListener, IReactionSet
Direct Known Subclasses:
ReactionScheme

public class ReactionSet extends ChemObject implements Serializable, IReactionSet, IChemObjectListener, Cloneable
A set of reactions, for example those taking part in a reaction. To retrieve the reactions from the set, there are two options:
 Iterator reactions = reactionSet.reactions();
 while (reactions.hasNext()) {
     IReaction reaction = (IReaction)reactions.next();
 }
 
and

 for (int i=0; i < reactionSet.getReactionCount(); i++) {
    IReaction reaction = reactionSet.getReaction(i);
 }
 
See Also:
Keywords:
reaction