Package org.openscience.cdk
Class Strand
java.lang.Object
org.openscience.cdk.ChemObject
org.openscience.cdk.AtomContainer
org.openscience.cdk.Strand
- All Implemented Interfaces:
Serializable,Cloneable,IAtomContainer,ICDKObject,IChemObject,IChemObjectListener,IStrand
A Strand is an AtomContainer which stores additional strand specific
informations for a group of Atoms.
- Author:
- Martin Eklund <[email protected]>, Ola Spjuth <[email protected]>
- See Also:
- Created on:
- 2004-12-20
-
Field Summary
Fields inherited from interface org.openscience.cdk.interfaces.IChemObject
ALIPHATIC, AROMATIC, CONJUGATED, HYDROGEN_BOND_ACCEPTOR, HYDROGEN_BOND_DONOR, IN_RING, MAPPED, MARKUSH, NOT_IN_RING, PLACED, REACTIVE_CENTER, SINGLE_OR_DOUBLE, TYPEABLE, VISITED -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidAdds the atom oAtom without specifying a Monomer or a Strand.voidAdds the atom oAtom to a specific Monomer.clone()Clones thisIChemObject.getMonomer(String cName) Retrieves a Monomer object by specifying its name.intReturns the number of monomers present in the Strand.Returns a collection of the names of allMonomers in this polymer.Returns a hashtable containing the monomers in the strand.Retrieves the strand name.Retrieves the strand type.voidremoveMonomer(String name) Removes a particular monomer, specified by its name.voidsetStrandName(String cStrandName) Sets the name of the Strand object.voidsetStrandType(String cStrandType) Sets the type of the Strand object.toString()Methods inherited from class org.openscience.cdk.AtomContainer
add, addBond, addBond, addBond, addElectronContainer, addLonePair, addLonePair, addSingleElectron, addSingleElectron, addStereoElement, atoms, bonds, contains, contains, contains, contains, contains, electronContainers, getAtom, getAtomCount, getAtomNumber, getBond, getBond, getBondCount, getBondNumber, getBondNumber, getBondOrderSum, getConnectedAtomsCount, getConnectedAtomsList, getConnectedBondsCount, getConnectedBondsCount, getConnectedBondsList, getConnectedElectronContainersList, getConnectedLonePairsCount, getConnectedLonePairsList, getConnectedSingleElectronsCount, getConnectedSingleElectronsList, getElectronContainer, getElectronContainerCount, getFirstAtom, getLastAtom, getLonePair, getLonePairCount, getLonePairNumber, getMaximumBondOrder, getMinimumBondOrder, getSingleElectron, getSingleElectronCount, getSingleElectronNumber, getTitle, indexOf, indexOf, indexOf, indexOf, isEmpty, lonePairs, newAtom, newAtom, newBond, remove, removeAllBonds, removeAllElectronContainers, removeAllElements, removeAtom, removeAtom, removeAtomAndConnectedElectronContainers, removeAtomOnly, removeAtomOnly, removeBond, removeBond, removeBond, removeElectronContainer, removeElectronContainer, removeLonePair, removeLonePair, removeSingleElectron, removeSingleElectron, setAtom, setAtoms, setBonds, setStereoElements, setTitle, shallowCopy, singleElectrons, stateChanged, stereoElementsMethods inherited from class org.openscience.cdk.ChemObject
addListener, addProperties, clear, compare, flags, getBuilder, getFlag, getFlags, getFlagValue, getID, getListenerCount, getNotification, getProperties, getProperty, getProperty, is, notifyChanged, notifyChanged, removeListener, removeProperty, set, setFlag, setFlags, setID, setNotification, setProperties, setPropertyMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.openscience.cdk.interfaces.IAtomContainer
add, addBond, addBond, addBond, addBond, addElectronContainer, addLonePair, addLonePair, addSingleElectron, addSingleElectron, addStereoElement, atoms, bonds, contains, contains, contains, contains, contains, electronContainers, getAtom, getAtomCount, getAtomNumber, getBond, getBond, getBondCount, getBondNumber, getBondNumber, getBondOrderSum, getConnectedAtomsCount, getConnectedAtomsList, getConnectedBondsCount, getConnectedBondsCount, getConnectedBondsList, getConnectedElectronContainersList, getConnectedLonePairsCount, getConnectedLonePairsList, getConnectedSingleElectronsCount, getConnectedSingleElectronsList, getElectronContainer, getElectronContainerCount, getFirstAtom, getLastAtom, getLonePair, getLonePairCount, getLonePairNumber, getMaximumBondOrder, getMinimumBondOrder, getSingleElectron, getSingleElectronCount, getSingleElectronNumber, getTitle, indexOf, indexOf, indexOf, indexOf, isEmpty, lonePairs, newAtom, newAtom, newAtom, newAtom, newBond, newBond, remove, removeAllBonds, removeAllElectronContainers, removeAllElements, removeAtom, removeAtom, removeAtomAndConnectedElectronContainers, removeAtomOnly, removeAtomOnly, removeBond, removeBond, removeBond, removeElectronContainer, removeElectronContainer, removeLonePair, removeLonePair, removeSingleElectron, removeSingleElectron, setAtom, setAtoms, setBonds, setStereoElements, setTitle, singleElectrons, stereoElementsMethods inherited from interface org.openscience.cdk.interfaces.ICDKObject
getBuilderMethods inherited from interface org.openscience.cdk.interfaces.IChemObject
addListener, addProperties, clear, flags, getFlag, getFlags, getFlagValue, getID, getListenerCount, getNotification, getProperties, getProperty, getProperty, is, notifyChanged, notifyChanged, removeListener, removeProperty, set, setFlag, setFlags, setID, setNotification, setProperties, setPropertyMethods inherited from interface org.openscience.cdk.interfaces.IChemObjectListener
stateChanged
-
Constructor Details
-
Strand
public Strand()Constructs a new Strand.
-
-
Method Details
-
getStrandName
Retrieves the strand name.- Specified by:
getStrandNamein interfaceIStrand- Returns:
- The name of the Strand object
- See Also:
-
getStrandType
Retrieves the strand type.- Specified by:
getStrandTypein interfaceIStrand- Returns:
- The type of the Strand object
- See Also:
-
setStrandName
Sets the name of the Strand object.- Specified by:
setStrandNamein interfaceIStrand- Parameters:
cStrandName- The new name for this strand- See Also:
-
setStrandType
Sets the type of the Strand object.- Specified by:
setStrandTypein interfaceIStrand- Parameters:
cStrandType- The new type for this strand- See Also:
-
addAtom
Adds the atom oAtom without specifying a Monomer or a Strand. Therefore the atom gets added to a Monomer of type UNKNOWN in a Strand of type UNKNOWN.- Specified by:
addAtomin interfaceIAtomContainer- Specified by:
addAtomin interfaceIStrand- Overrides:
addAtomin classAtomContainer- Parameters:
oAtom- The atom to add
-
addAtom
Adds the atom oAtom to a specific Monomer. -
getMonomerCount
public int getMonomerCount()Returns the number of monomers present in the Strand.- Specified by:
getMonomerCountin interfaceIStrand- Returns:
- number of monomers
-
getMonomer
Retrieves a Monomer object by specifying its name.- Specified by:
getMonomerin interfaceIStrand- Parameters:
cName- The name of the monomer to look for- Returns:
- The Monomer object which was asked for
-
getMonomerNames
Returns a collection of the names of allMonomers in this polymer.- Specified by:
getMonomerNamesin interfaceIStrand- Returns:
- a
Collectionof all the monomer names.
-
removeMonomer
Removes a particular monomer, specified by its name.- Specified by:
removeMonomerin interfaceIStrand- Parameters:
name- The name of the monomer to remove
-
getMonomers
Returns a hashtable containing the monomers in the strand.- Specified by:
getMonomersin interfaceIStrand- Returns:
- hashtable containing the monomers in the strand.
-
toString
Description copied from class:AtomContainer- Specified by:
toStringin interfaceIChemObject- Overrides:
toStringin classAtomContainer
-
clone
Description copied from class:AtomContainerClones thisIChemObject. It clones the identifier, flags, properties and pointer vectors. The ChemObjectListeners are not cloned, and neither is the content of the pointer vectors.- Specified by:
clonein interfaceIAtomContainer- Specified by:
clonein interfaceIChemObject- Specified by:
clonein interfaceIStrand- Overrides:
clonein classAtomContainer- Returns:
- The cloned object
- Throws:
CloneNotSupportedException
-