-
-
- serialVersionUID:
- -5032283549467862509L
-
- serialVersionUID:
- -3137373012494608794L
-
Serialized Fields
-
charge
Double charge
The partial charge of the atom.
The default value is
CDKConstants.UNSET and serves to provide a check whether the charge has been
set or not
-
fractionalPoint3d
javax.vecmath.Point3d fractionalPoint3d
A 3 point specifying the location of this atom in a crystal unit cell.
-
hydrogenCount
Integer hydrogenCount
The number of implicitly bound hydrogen atoms for this atom.
-
point2d
javax.vecmath.Point2d point2d
A 2D point specifying the location of this atom in a 2D coordinate
space.
-
point3d
javax.vecmath.Point3d point3d
A 3 point specifying the location of this atom in a 3D coordinate
space.
-
stereoParity
Integer stereoParity
A stereo parity descriptor for the stereochemistry of this atom.
-
-
- serialVersionUID:
- 5678100348445919254L
-
Serialized Fields
-
atomCount
int atomCount
Number of atoms contained by this object.
-
atoms
IAtom[] atoms
Internal array of atoms.
-
bondCount
int bondCount
Number of bonds contained by this object.
-
bonds
IBond[] bonds
Internal array of bonds.
-
growArraySize
int growArraySize
Amount by which the bond and atom arrays grow when elements are added and
the arrays are not large enough for that.
-
lonePairCount
int lonePairCount
Number of lone pairs contained by this object.
-
lonePairs
ILonePair[] lonePairs
Internal array of lone pairs.
-
singleElectronCount
int singleElectronCount
Number of single electrons contained by this object.
-
singleElectrons
ISingleElectron[] singleElectrons
Internal array of single electrons.
-
stereoElements
List<IStereoElement> stereoElements
Internal list of atom parities.
-
- serialVersionUID:
- -521290255592768395L
-
Serialized Fields
-
atomContainerCount
int atomContainerCount
Number of AtomContainers contained by this container.
-
atomContainers
IAtomContainer[] atomContainers
Array of AtomContainers.
-
growArraySize
int growArraySize
Amount by which the AtomContainers array grows when elements are added and
the array is not large enough for that.
-
multipliers
Double[] multipliers
Defines the number of instances of a certain molecule
in the set. It is 1 by default.
-
- serialVersionUID:
- -7950397716808229972L
-
Serialized Fields
-
bondOrderSum
Double bondOrderSum
The maximum sum of all bond orders allowed for this atom type.
-
covalentRadius
Double covalentRadius
The covalent radius of this atom type.
-
electronValency
Integer electronValency
The electron Valency of this atom with CDKConstants.UNSET as default.
-
formalCharge
Integer formalCharge
-
formalNeighbourCount
Integer formalNeighbourCount
The formal number of neighbours this atom type can have with CDKConstants_UNSET
as default. This includes explicitely and implicitly connected atoms, including
implicit hydrogens.
-
hybridization
IAtomType.Hybridization hybridization
The hybridization state of this atom with CDKConstants.HYBRIDIZATION_UNSET
as default.
-
identifier
String identifier
String representing the identifier for this atom type with null as default.
-
maxBondOrder
IBond.Order maxBondOrder
The maximum bond order allowed for this atom type.
-
- serialVersionUID:
- -5001873073769634393L
-
- serialVersionUID:
- 7057060562283387384L
-
Serialized Fields
-
atomCount
int atomCount
Number of atoms contained by this object.
-
atoms
IAtom[] atoms
A list of atoms participating in this bond.
-
display
IBond.Display display
-
order
IBond.Order order
The bond order of this bond.
-
- serialVersionUID:
- 1926781734333430132L
-
Serialized Fields
-
chemSequenceCount
int chemSequenceCount
Number of ChemSequences contained by this container.
-
chemSequences
IChemSequence[] chemSequences
Array of ChemSquences.
-
growArraySize
int growArraySize
Amount by which the chemsequence array grows when elements are added and
the array is not large enough for that.
-
- serialVersionUID:
- -5213425310451366185L
-
- serialVersionUID:
- 2798134548764323328L
-
Serialized Fields
-
chemObjectListeners
List<IChemObjectListener> chemObjectListeners
List for listener administration.
-
doNotification
boolean doNotification
-
flags
int flags
You will frequently have to use some flags on a IChemObject. For example, if
you want to draw a molecule and see if you've already drawn an atom, or in
a ring search to check whether a vertex has been visited in a graph
traversal. Use these flags while addressing particular positions in the
flag array with self-defined constants (flags[VISITED] = true). 100 flags
per object should be more than enough.
-
identifier
String identifier
The ID is null by default.
-
properties
Map<Object,Object> properties
A hashtable for the storage of any kind of properties of this IChemObject.
-
- serialVersionUID:
- 2199218627455492000L
-
- serialVersionUID:
- 5919649450390509278L
-
Serialized Fields
-
aAxis
javax.vecmath.Vector3d aAxis
The a axis.
-
bAxis
javax.vecmath.Vector3d bAxis
The b axis.
-
cAxis
javax.vecmath.Vector3d cAxis
The c axis.
-
spaceGroup
String spaceGroup
Number of symmetry related atoms.
-
zValue
Integer zValue
Number of symmetry related atoms.
-
- serialVersionUID:
- -2207894536767670743L
-
- serialVersionUID:
- 3062529834691231436L
-
- serialVersionUID:
- -6144605920605752463L
-
- serialVersionUID:
- 6389365978927575858L
-
Serialized Fields
-
exactMass
Double exactMass
Exact mass of this isotope.
-
massNumber
Integer massNumber
The mass number for this isotope.
-
naturalAbundance
Double naturalAbundance
Natural abundance of this isotope.
-
- serialVersionUID:
- 51311422004885329L
-
- serialVersionUID:
- -6541914644492043503L
-
- serialVersionUID:
- -6084164963937650703L
-
- serialVersionUID:
- -2596790658835319339L
-
- serialVersionUID:
- 1L
-
Serialized Fields
-
attachPoint
int attachPoint
-
label
String label
-
- serialVersionUID:
- -554752558363533678L
-
- serialVersionUID:
- -3676327644698347260L
-
- serialVersionUID:
- 1555749911904585204L
-
- serialVersionUID:
- 6604894792331865990L
-
- serialVersionUID:
- 7168431521057961434L
-
- serialVersionUID:
- 7796574734668490940L
-
- serialVersionUID:
- 4200943086350928356L
-
Serialized Fields
-
monomers
Map<String,IMonomer> monomers
The list of all Monomers in the Strand.
-
strandName
String strandName
The name of this strand (e.g. A, B).
-
strandType
String strandType
The type of this strand (e.g. PEPTIDE, DNA, RNA).
-
- serialVersionUID:
- -4819492883237421487L
-
-
- serialVersionUID:
- 5418604788783986725L
-
-
- serialVersionUID:
- 7670650135045832543L
-
Serialized Fields
-
altLoc
String altLoc
-
chainID
String chainID
-
hetAtom
boolean hetAtom
-
iCode
String iCode
-
name
String name
-
occupancy
double occupancy
-
oxt
boolean oxt
-
record
String record
-
resName
String resName
-
resSeq
String resSeq
-
segID
String segID
-
serial
int serial
-
tempFactor
double tempFactor
-
- serialVersionUID:
- -7236625816763776733L
-
- serialVersionUID:
- 4173552834313952358L
-
- serialVersionUID:
- -1877529009319324448L
-
Serialized Fields
-
endChainID
Character endChainID
-
endInsertionCode
Character endInsertionCode
-
endSequenceNumber
Integer endSequenceNumber
-
startChainID
Character startChainID
-
startInsertionCode
Character startInsertionCode
-
startSequenceNumber
Integer startSequenceNumber
-
structureType
String structureType