Package org.openscience.cdk
Class Mapping
java.lang.Object
org.openscience.cdk.ChemObject
org.openscience.cdk.Mapping
- All Implemented Interfaces:
Serializable,Cloneable,ICDKObject,IChemObject,IMapping
A Mapping is an relation between two ChemObjects in a non-chemical
entity. It is not a Bond, nor a Association, merely a relation.
An example of such a mapping, is the mapping between corresponding atoms
in a Reaction.
- Author:
- Egon Willighagen
- See Also:
- Keywords:
- reaction, atom mapping
- Created on:
- 2003-08-16
-
Field Summary
Fields inherited from interface org.openscience.cdk.interfaces.IChemObject
ALIPHATIC, AROMATIC, CONJUGATED, HYDROGEN_BOND_ACCEPTOR, HYDROGEN_BOND_DONOR, IN_RING, MAPPED, MARKUSH, NOT_IN_RING, PLACED, REACTIVE_CENTER, SINGLE_OR_DOUBLE, TYPEABLE, VISITED -
Constructor Summary
ConstructorsConstructorDescriptionMapping(IChemObject objectOne, IChemObject objectTwo) Constructs an unconnected lone pair. -
Method Summary
Modifier and TypeMethodDescriptionclone()Clones thisMappingand the mappedIChemObjects.getChemObject(int pos) Retrieves the first or second of the related IChemObjects.Returns an Iterable to the two IChemObjects.Methods inherited from class org.openscience.cdk.ChemObject
addListener, addProperties, clear, compare, flags, getBuilder, getFlag, getFlags, getFlagValue, getID, getListenerCount, getNotification, getProperties, getProperty, getProperty, is, notifyChanged, notifyChanged, removeListener, removeProperty, set, setFlag, setFlags, setID, setNotification, setProperties, setProperty, shallowCopyMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.openscience.cdk.interfaces.ICDKObject
getBuilderMethods inherited from interface org.openscience.cdk.interfaces.IChemObject
addListener, addProperties, clear, flags, getFlag, getFlags, getFlagValue, getID, getListenerCount, getNotification, getProperties, getProperty, getProperty, is, notifyChanged, notifyChanged, removeListener, removeProperty, set, setFlag, setFlags, setID, setNotification, setProperties, setProperty, toString
-
Constructor Details
-
Mapping
Constructs an unconnected lone pair.- Parameters:
objectOne- The first IChemObject of the mappingobjectTwo- The second IChemObject of the mapping
-
-
Method Details
-
getChemObject
Retrieves the first or second of the related IChemObjects.- Specified by:
getChemObjectin interfaceIMapping- Parameters:
pos- The position of the IChemObject.- Returns:
- The IChemObject to retrieve.
-
clone
Clones thisMappingand the mappedIChemObjects.- Specified by:
clonein interfaceIChemObject- Overrides:
clonein classChemObject- Returns:
- The cloned object
- Throws:
CloneNotSupportedException